smf/smfservermodule/smfclient/smfactivityfetcher_p.h
changeset 25 a180113055cb
parent 18 013a02bf2bb0
--- a/smf/smfservermodule/smfclient/smfactivityfetcher_p.h	Thu Sep 23 17:20:22 2010 +0530
+++ b/smf/smfservermodule/smfclient/smfactivityfetcher_p.h	Thu Sep 23 17:43:31 2010 +0530
@@ -51,30 +51,42 @@
 	~SmfActivityFetcherPrivate();
 	
 	/**
 	 * Emits signal resultsAvailable() when list of activities for the user is available 
 	 */
-	void selfActivities(int pageNum, int perPage);
+	SmfError selfActivities(int pageNum, int perPage);
 
 	/**
 	 * Emits signal resultsAvailable() when list of activities for other contact  is available 
 	 */
-	void friendsActivities(const SmfContact& aFriend, int pageNum, int perPage);
+	SmfError friendsActivities(const SmfContact& aFriend, int pageNum, int perPage);
 	
 	/**
 	 * returns only those activities (self) which are from @arg filters
+	 * @return SmfError. SmfNoError if success, else appropriate error code
 	 */
-	void filtered(QList<SmfActivityObjectType> filters, int pageNum, int perPage);
+	SmfError filtered(QList<SmfActivityObjectType> filters, int pageNum, int perPage);
 	
 	/**
 	 * Request for a custom operation. The signal customDataAvailable() is emitted 
 	 * when the result is available.
 	 * @param operationId OperationId
 	 * @param customData Custom data to be sent
+	 * @return SmfError. SmfNoError if success, else appropriate error code
 	 * Note:-Interpretation of operationId and customData is upto the concerned
 	 * plugin and client application. service provider should provide some
 	 * serializing-deserializing utilities for these custom data
 	 */
-	void customRequest ( const int& operationId, QByteArray* customData );
+	SmfError customRequest ( const int& operationId, QByteArray* customData );
+	
+    /**
+     * Cancels a request generated due to the call to any API which results 
+     * into http request. Might return error if no request is currently pending.
+     * Please note that there can be only one request pending at any point of time
+     * @return Appropriate SmfError value
+     */
+	SmfError cancelRequest ();
 	
 public: //From smfObserver
 	/**
@@ -94,7 +106,7 @@
 	  SmfClientQt* m_SmfClientPrivate;
 	  friend class SmfClientQt;
 #endif
-	  int m_argFlag;
+	  quint8 m_argFlag;
 	  //serialized byte array of provider+other info to be sent to the server
 	  //The order:- SmfProvider then params in order of their appearance in fn
 	  QByteArray m_serializedDataToServer;
@@ -51,30 +51,42 @@
 	
 	/**
-	 * Emits signal resultsAvailable() when list of activities for the user is available 
+	 * Emits signal resultsAvailable() when list of activities for the user is available
+	 * @return SmfError. SmfNoError if success, else appropriate error code 
 	 */
@@ -51,30 +51,42 @@
 
 	/**
-	 * Emits signal resultsAvailable() when list of activities for other contact  is available 
+	 * Emits signal resultsAvailable() when list of activities for other contact  is available
+	 * @return SmfError. SmfNoError if success, else appropriate error code 
 	 */